@@ -18,6 +18,7 @@ DISKS = [{'size': DISKSIZE, 'default': True}]
 GUESTID = 'guestrhel764'
 VNC = True
 CLOUDINIT = True
+GUESTAGENT = True
 RESERVEIP = False
 RESERVEDNS = False
 RESERVEHOST = False
@@ -31,17 +32,18 @@ TUNNELDIR = '/var/www/html'
 TUNNELPORT = 22
 VMUSER = None
 VMPORT = None
-OPENSHIFT_TAG = '4.16'
+OPENSHIFT_TAG = '4.19'
 ALMA = 'https://repo.ifca.es/almalinux'
 BSD = 'https://object-storage.public.mtl1.vexxhost.net/swift/v1/1dbafeefbd4f4c80864414a441e72dd2'
 BSD += '/bsd-cloud-image.org/images/dragonflybsd'
 CENTOS = 'https://cloud.centos.org/centos'
 DEBIAN = 'https://cdimage.debian.org/cdimage'
+EULER = 'https://mirror.accum.se/mirror/openeuler.org/openEuler'
 FEDORA = 'http://mirror.uv.es/mirror/fedora/linux/releases'
 GENTOO = 'https://gentoo.osuosl.org/experimental/amd64/openstack'
-SUSE = 'https://download.opensuse.org'
 RHCOS = 'https://mirror.openshift.com/pub/openshift-v4/dependencies/rhcos'
 ROCKY = 'https://dl.rockylinux.org/pub/rocky/'
+SUSE = 'https://download.opensuse.org'
 UBUNTU = 'https://cloud-images.ubuntu.com/releases'
 IMAGES = {'almalinux8': f'{ALMA}/8/cloud/x86_64/images/AlmaLinux-8-GenericCloud-latest.x86_64.qcow2',
           'almalinux9': f'{ALMA}/9/cloud/x86_64/images/AlmaLinux-9-GenericCloud-latest.x86_64.qcow2',
@@ -49,15 +51,16 @@ IMAGES = {'almalinux8': f'{ALMA}/8/cloud/x86_64/images/AlmaLinux-8-GenericCloud-
           'centos7': f'{CENTOS}/7/images/CentOS-7-x86_64-GenericCloud.qcow2',
           'centos8stream': f'{CENTOS}/8-stream/x86_64/images/CentOS-Stream-GenericCloud-8-latest.x86_64.qcow2',
           'centos9stream': f'{CENTOS}/9-stream/x86_64/images/CentOS-Stream-GenericCloud-9-latest.x86_64.qcow2',
+          'centos10stream': f'{CENTOS}/10-stream/x86_64/images/CentOS-Stream-GenericCloud-10-latest.x86_64.qcow2',
           'cirros': 'http://download.cirros-cloud.net/0.5.2/cirros-0.5.2-x86_64-disk.img',
           'debian10': f'{DEBIAN}/openstack/current-10/debian-10-openstack-amd64.qcow2',
           'debian11': f'{DEBIAN}/cloud/bullseye/latest/debian-11-generic-amd64.qcow2',
           'debian12': f'{DEBIAN}/cloud/bookworm/latest/debian-12-generic-amd64.qcow2',
           'fcos': 'https://builds.coreos.fedoraproject.org/streams/stable.json',
-          'fedora37': f'{FEDORA}/37/Cloud/x86_64/images/Fedora-Cloud-Base-37-1.7.x86_64.qcow2',
-          'fedora38': f'{FEDORA}/38/Cloud/x86_64/images/Fedora-Cloud-Base-38-1.6.x86_64.qcow2',
           'fedora39': f'{FEDORA}/39/Cloud/x86_64/images/Fedora-Cloud-Base-39-1.5.x86_64.qcow2',
           'fedora40': f'{FEDORA}/40/Cloud/x86_64/images/Fedora-Cloud-Base-Generic.x86_64-40-1.14.qcow2',
+          'fedora41': f'{FEDORA}/41/Cloud/x86_64/images/Fedora-Cloud-Base-Generic-41-1.4.x86_64.qcow2',
+          'fedora42': f'{FEDORA}/42/Cloud/x86_64/images/Fedora-Cloud-Base-Generic-42-1.1.x86_64.qcow2',
           'fedoralatest': 'https://alt.fedoraproject.org/cloud',
           'freebsd122': f'{BSD}/freebsd/12.2/freebsd-12.2.qcow2',
           'freebsd130': f'{BSD}/freebsd/13.0/freebsd-13.0-zfs.qcow2',
@@ -68,6 +71,8 @@ IMAGES = {'almalinux8': f'{ALMA}/8/cloud/x86_64/images/AlmaLinux-8-GenericCloud-
           'dragonflybsd601': f'{BSD}/dragonflybsd/6.0.1/2021-12-11/dragonflybsd-6.0.1-hammer2.qcow2',
           'dragonflybsd622': f'{BSD}/dragonflybsd/6.2.2/2022-09-06/hammer2/dragonflybsd-6.2.2-hammer2-2022-09-06.qcow2',
           'gentoo': f'{GENTOO}/gentoo-openstack-amd64-default-latest.qcow2',
+          'openeuler2403': f'{EULER}-24.03-LTS/virtual_machine_img/x86_64/openEuler-24.03-LTS-x86_64.qcow2.xz',
+          'openeuler2409': f'{EULER}-24.09/virtual_machine_img/x86_64/openEuler-24.09-x86_64.qcow2.xz',
           'opensuse155': f'{SUSE}/repositories/Cloud:/Images:/Leap_15.5/images/openSUSE-Leap-15.5.x86_64-NoCloud.qcow2',
           'opensuse156': f'{SUSE}/repositories/Cloud:/Images:/Leap_15.6/images/openSUSE-Leap-15.6.x86_64-NoCloud.qcow2',
           'rhcos410': f'{RHCOS}/4.10',
@@ -77,16 +82,21 @@ IMAGES = {'almalinux8': f'{ALMA}/8/cloud/x86_64/images/AlmaLinux-8-GenericCloud-
           'rhcos414': f'{RHCOS}/4.14',
           'rhcos415': f'{RHCOS}/4.15',
           'rhcos416': f'{RHCOS}/4.16',
-          'rhcoslatest': f'{RHCOS}/4.16',
+          'rhcos417': f'{RHCOS}/4.17',
+          'rhcos418': f'{RHCOS}/4.18',
+          'rhcos419': f'{RHCOS}/4.19',
+          'rhcoslatest': f'{RHCOS}/{OPENSHIFT_TAG}',
           'rhel7': 'https://access.redhat.com/downloads/content/69/ver=/rhel---7',
           'rhel8': 'https://access.redhat.com/downloads/content/479/ver=/rhel---8',
           'rhel9': 'https://access.redhat.com/downloads/content/479/ver=/rhel---9',
+          'rhel10': 'https://access.redhat.com/downloads/content/479/ver=/rhel---10',
           'ubuntu1804': f'{UBUNTU}/18.04/release/ubuntu-18.04-server-cloudimg-amd64.img',
           'ubuntu2004': f'{UBUNTU}/20.04/release/ubuntu-20.04-server-cloudimg-amd64.img',
           'ubuntu2204': f'{UBUNTU}/22.04/release/ubuntu-22.04-server-cloudimg-amd64.img',
           'ubuntu2304': f'{UBUNTU}/23.04/release/ubuntu-23.04-server-cloudimg-amd64.img',
           'ubuntu2310': f'{UBUNTU}/23.10/release/ubuntu-23.10-server-cloudimg-amd64.img',
           'ubuntu2404': f'{UBUNTU}/24.04/release/ubuntu-24.04-server-cloudimg-amd64.img',
+          'ubuntu2410': f'{UBUNTU}/24.10/release/ubuntu-24.10-server-cloudimg-amd64.img',
           'rockylinux8': f'{ROCKY}/8/images/x86_64/Rocky-8-GenericCloud.latest.x86_64.qcow2',
           'rockylinux9': f'{ROCKY}/9/images/x86_64/Rocky-9-GenericCloud.latest.x86_64.qcow2'}
 
@@ -132,8 +142,6 @@ NOTIFYSCRIPT = None
 SLACKCHANNEL = None
 NOTIFYMETHODS = ['pushbullet']
 SHAREDFOLDERS = []
-KERNEL = None
-INITRD = None
 CMDLINE = None
 PLACEMENT = []
 YAMLINVENTORY = False
@@ -193,7 +201,7 @@ oEO8BRcXIiXiQqW9KnF99fXOiQ/cKYh3kWBBPnuEOhC77Ke5aMlqMNOPULf3PMix
 -----END CERTIFICATE-----"""
 VIRTTYPE = None
 METADATA_FIELDS = ['dnsclient', 'domain', 'image', 'kube', 'kubetype', 'loadbalancer', 'owner', 'plan', 'profile',
-                   'user', 'redfish_iso']
+                   'user', 'redfish_iso', 'cluster_network']
 VMRULES = []
 VMRULES_STRICT = False
 SECURITYGROUPS = []
@@ -218,7 +226,7 @@ StandardOutput=journal
 StandardError=journal
 Environment=HOME={home}
 Environment=PYTHONUNBUFFERED=true
-{port}{ipv6}{ssl}{user}{password}{bootonce}
+{port}{user}{password}{bootonce}
 [Install]
 WantedBy=multi-user.target"""
 
@@ -232,7 +240,7 @@ StandardOutput=journal
 StandardError=journal
 Environment=HOME={home}
 Environment=PYTHONUNBUFFERED=true
-{port}{ipv6}
+{port}
 [Install]
 WantedBy=multi-user.target"""
 
@@ -248,8 +256,7 @@ IBM = {'region': 'eu-gb'}
 GCP = {'region': 'europe-west1'}
 
 KUBEVIRT = {'readwritemany': False, 'disk_hotplug': False, 'access_mode': 'NodePort',
-            'volume_mode': 'Filesystem', 'volume_access': 'ReadWriteOnce', 'harvester': False, 'embed_userdata': False,
-            'first_consumer': False}
+            'harvester': False, 'embed_userdata': False, 'registry': 'quay.io'}
 
 OPENSTACK = {'version': '2', 'domain': 'Default', 'user': 'admin', 'project': 'admin'}
 
@@ -257,4 +264,6 @@ OVIRT = {'datacenter': 'Default', 'cluster': 'Default', 'user': 'admin@internal'
          'filteruser': False}
 
 VSPHERE = {'force_pool': False, 'dvs': True, 'restricted': False, 'import_network': 'VM Network',
-           'filtervms': False, 'filteruser': False, 'category': 'kcli', 'timeout': 2700, 'serial': False}
+           'filtervms': False, 'filteruser': False, 'category': 'kcli', 'timeout': 3600, 'serial': False}
+
+CLUSTERNAMES = {'openshift': 'myopenshift'}
