@@ -22,7 +22,7 @@ $ kcli create dns -n network2 -d karmalabs.corp -i 192.168.122.253 api.jhendrix
 $ kcli create dns -d karmalabs.corp -i 104.197.157.226 -a '*' api.jhendrix
 """
 
-hostcreate = """# Add a kvm host
+hostcreate = """# Add a KVM host
 $ kcli create host kvm -H 192.168.1.6 twix
 
 # Add an aws host
@@ -40,7 +40,7 @@ $ kcli create host vsphere -c mycluster -d mydatacenter -H 192.168.1.3 -u admin@
 # Add an openstack host
 $ kcli create host openstack --auth-url http://10.19.114.91:5000/v3 -u admin -p pass --project myproject myosp
 
-# Add a kubevirt host using existing k8s credentials
+# Add a KubeVirt host using existing k8s credentials
 $ kcli create host kubevirt mykubevirt
 
 # Add an ibm host
@@ -66,9 +66,6 @@ $ kcli list vm
 # Get list of vms from all hosts/clients
 $ kcli -C all list vm
 
-# Get list of products
-$ kcli list product
-
 # Get list of clients/hosts
 $ kcli list host
 """
@@ -93,6 +90,9 @@ $ kcli create plan -f multi.yml -P ctlplanes=1 -P nodes=2 -P crio=true
 # Create a plan from a remote url, customizing some parameters
 $ kcli create plan -u https://github.com/karmab/kcli-plans/blob/main/kubernetes/kubernetes.yml -P ctlplanes=3
 
+# Skip pre check
+$ kcli create plan -f multi.yml -P pre=false
+
 # Run plan treating vm with installer in its name as a workflow
 $ kcli create plan -P installer_workflow=true
 """
@@ -102,14 +102,18 @@ $ kcli info plan -f multi.yml
 
 # Get info of a plan with a remote url
 $ kcli info plan -u https://github.com/karmab/kcli-plans/blob/main/kubernetes/kubernetes.yml
-"""
 
-productinfo = """# Get info from product kubernetes
-$ kcli info product kubernetes
-"""
+# Get info for a specific running plan
+$ kcli info plan myplan
 
-repocreate = """# Create a product repo from karmab samples repo
-$ kcli create repo -u https://github.com/karmab/kcli-plans karmab
+# Filter information for a specific plan
+$ kcli info plan myplan -P field=status
+
+# Filter information for a specific plan and a specific vm
+$ kcli info plan myplan -P field=status -P name=myvm01
+
+# Get all vms of a specific plan which are down
+$ kcli info plan myplan -P field=status -P value=down
 """
 
 start = """# Start vms named vm1 and vm2
@@ -128,6 +132,9 @@ $ kcli create vm -i centos9stream
 # Create a centos vm named myvm customizing its memory and cpus
 $ kcli create vm -i centos9stream -P memory=4096 -P numcpus=4 myvm
 
+# Create a centos vm named myvm with specific cpu topology
+$ kcli create vm -i centos9stream -P cores=4 -P sockets=2 -P threads=2 myvm
+
 # Pass disks, networks and even cmds
 $ kcli create vm -i centos9stream -P disks=[10,20] -P nets=[default] -P cmds=['yum -y install nc']
 
@@ -177,14 +184,17 @@ $ kcli create vm -P iso=xxx.iso myvm
 # Create a GCP vm with 2 nvidia-tesla-t4 gpus
 $ kcli create vm -i ubuntu-minimal-2204-lts -P gpus=['{"type": "nvidia-tesla-t4", "count": 2}'] myvm
 
-# Create 3 vm to emulate baremetal
+# Create 3 vms to emulate baremetal
 $ kcli create vm -P start=false -P memory=20480 -P numcpus=16 -P disks=[200] -P uefi=true -P nets=[default] -c 3 myclu
 
-# Create an sriov enabled vm (on KVM only)
+# Create a KubeVirt vm on a specific host
+$ kcli create vm -i centos9stream -P host=mynode1
+
+# Create an sriov enabled vm (KVM specific)
 $ kcli create vm -i centos9stream -P nets=['{"name": "default"}','{"name": "default", "sriov": "true"}']
 """
 
-vmconsole = """# Open a graphical console for vm ( only shows the command if using container)
+vmconsole = """# Open a graphical console for vm (only show the command if using container)
 $ kcli console myvm
 
 # Get a serial console to the vm
@@ -202,7 +212,10 @@ $ kcli create kube aks -P network=subnet-1 myaks
 $ kcli create kube aks --paramfile=myparameters.yml myaks
 """
 
-kubeekscreate = """# Create an eks instance named myeks (specifying two subnets in different AZs)
+kubeekscreate = """# Create an eks instance named myeks on current vpc
+$ kcli create kube eks myeks
+
+# Create an eks instance named myeks (specifying two subnets in different AZs)
 $ kcli create kube eks -P network=subnet-1 -P extra_networks=[subnet-2] myeks
 
 # Specify custom role for ctlplane
@@ -341,26 +354,31 @@ $ kcli create openshift-iso -P nets=['{"ip":"192.168.0.8","netmask":"24","gatewa
 $ kcli create openshift-iso -P extra_args="super_string_of_args" myopenshift.karmalabs.corp
 """
 
-disconnectedcreate = """# Generate an openshift disconnected vm for 4.16
-$ kcli create openshift-registry -P version=stable -P tag='4.16'
+kubeadmregistrycreate = """# Generate a kubeadm/generic registry vm for latest kubeadm
+$ kcli create registry kubeadm
+"""
+
+openshiftregistrycreate = """# Generate an openshift registry vm for 4.19
+$ kcli create registry openshift -P version=stable -P tag='4.19'
 
 # Do the same over an ipv4 network
-$ kcli create openshift-registry -P version=nightly -P tag='4.16' -P disconnected_ipv6_network=false
+$ kcli create registry openshift -P version=nightly -P tag='4.19' -P disconnected_ipv6_network=false
 
-# Use specific version and add extra operators (from 4.16)
-$ kcli create openshift-registry -P version=nightly -P tag=4.16 -P disconnected_operators=[sriov-network-operator]
+# Use specific version and add extra operators (from 4.18)
+$ kcli create registry openshift -P version=nightly -P tag='4.19' -P disconnected_operators=[sriov-network-operator]
 
 # Deploy registry without content
-$ kcli create openshift-registry -P disconnected_sync=false
+$ kcli create registry openshift -P disconnected_sync=false
 """
 
-disconnectedupdate = """# Update openshift disconnected registry for 4.16
-$ kcli update openshift-registry -P version=stable -P tag='4.16' -P disconnected_url=192.168.122.200.sslip.io:5000 myreg
+openshiftregistryupdate = """# Update openshift registry for 4.19
+$ kcli update openshift-registry -P version=stable -P tag='4.19' -P disconnected_url=192.168.122.200.sslip.io:5000 myreg
 
-# Update openshift disconnected registry taking parameter from existing cluster install named myopenshift
-$ kcli update openshift-registry -P tag='4.16.0' myopenshift
+# Update openshift registry taking parameter from existing cluster install named myopenshift
+$ kcli update openshift-registry -P tag='4.19.0' myopenshift
 """
 
+
 appopenshiftcreate = """# Deploy sriov network operator
 $ kcli create app openshift sriov-network-operator
 
@@ -402,27 +420,33 @@ $ kcli download image centos9stream -P pool=mypool
 # Download specific arch
 $ kcli download image centos9stream -P arch=aarch64
 
-# Execute command after download
-$ kcli download image centos9stream -P cmd='echo welcome here > /etc/motd'
+# Execute commands after download
+$ kcli download image centos9stream -P cmds=['echo welcome here > /etc/motd']
 
 # Download with specific name
 $ kcli download image centos9stream -P name=centos9
 
-# Force the size (kubevirt specific)
+# Force the size (KubeVirt specific)
 $ kcli download image rhcoslatest -P size=40
 
-# Download qemu variant for rhcos (kvm specific)
+# Download qemu variant for rhcos (KVM specific)
 $ kcli download image rhcoslatest -P qemu=true
 
 # Download rhcos associated to current openshift-installer
 $ kcli download image rhcoslatest -P installer=true
 
 # Download image from specific url
-$ kcli download image -u http://super.qcow2 super
+$ kcli download image -P url=http://super.qcow2 super
+
+# Alternative way
+$ kcli download iso -u http://super.qcow2 super
 """
 
 isodownload = """# Download debian iso
-$ kcli download iso -P url=https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-11.1.0-amd64-netinst.iso
+$ kcli download iso -P url=https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-12.6.0-amd64-netinst.iso
+
+# Alternative way
+$ kcli download iso -u https://cdimage.debian.org/debian-cd/current/amd64/iso-cd/debian-12.6.0-amd64-netinst.iso
 
 # Download iso to specific pool
 $ kcli download iso -P url=http://super.iso -P pool=mypool
@@ -552,131 +576,85 @@ $ kcli update network mynetwork --domain superdomain.com
 $ kcli update network mynetwork -P plan=newplan
 """
 
-resethosts = """# Reset bare metal hosts declared in a parameter file
-
-$ kcli reset baremetal-hosts --pf baremetal_hosts.yml
-
-baremetal_hosts.yml contains
-bmc_user: admin
-bmc_password: admin
-baremetal_hosts:
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm1
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm2
-
-# Reset a single host
+resethost = """# Reset a baremetal host
 $ kcli reset baremetal-host -P user=admin -P password=admin 10.10.10.10
 
-# Reset a single host with dedicated flags for credentials
+# Reset a baremetal host with dedicated flags for credentials
 $ kcli reset baremetal-host -u admin -p admin 10.10.10.10
 """
 
-starthosts = """# Start bare metal hosts declared in a parameter file from specific ISO url
-
-$ kcli start baremetal-hosts --pf baremetal_hosts.yml -P iso_url=http://192.168.122.1/my.iso
-
-baremetal_hosts.yml contains
-bmc_user: admin
-bmc_password: admin
-baremetal_hosts:
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm1
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm2
-
-# Start a single host
+starthost = """# Start a baremetal host
 $ kcli start baremetal-host -P user=admin -P password=admin 10.10.10.10
 
-# Start a single host with dedicated flags for credentials
+# Start a baremetal host with dedicated flags for credentials
 $ kcli start baremetal-host -u admin -p admin 10.10.10.10
+
+# Start a baremetal host with a specific iso
+$ kcli start baremetal-host -u admin -p admin -P iso_url=http://192.168.122.1/my.iso 10.10.10.10
 """
 
-stophosts = """# Stop bare metal hosts declared in a parameter file
-
-$ kcli stop baremetalhosts --pf baremetal_hosts.yml
-
-baremetal_hosts.yml contains
-bmc_user: admin
-bmc_password: admin
-baremetal_hosts:
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm1
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm2
-
-# Stop a single host
+stophost = """# Stop a baremetal host
 $ kcli stop baremetal-host -P user=admin -P password=admin 10.10.10.10
 
-# Stop a single host with dedicated flags for credentials
+# Stop a baremetal host with dedicated flags for credentials
 $ kcli stop baremetal-host -u admin -p admin 10.10.10.10
 """
 
-infohosts = """# Report info on Baremetal hosts declared in a parameter file
-
-$ kcli info baremetalhosts --pf baremetal_hosts.yml
-
-baremetal_hosts.yml contains
-bmc_user: admin
-bmc_password: admin
-baremetal_hosts:
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm1
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm2
-
-# Report info on a single host
+infohost = """# Get info on a baremetal host
 $ kcli info baremetal-host -P user=admin -P password=admin 10.10.10.10
 
-# Report info on a single host with dedicated flags for credentials
+# Report info on a baremetal host with dedicated flags for credentials
 $ kcli info baremetal-host -u admin -p admin 10.10.10.10
 """
 
-updatehosts = """# Update bare metal hosts declared in a parameter file
-
-$ kcli update baremetal-hosts --pf baremetal_hosts.yml -P secureboot=true
-
-baremetal_hosts.yml contains
-bmc_user: admin
-bmc_password: admin
-baremetal_hosts:
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm1
-- bmc_url: http://192.168.122.1:9000/redfish/v1/Systems/local/vm2
-
-# Update a single host
+updatehost = """# Update a baremetal host
 $ kcli update baremetal-host -P user=admin -P password=admin 10.10.10.10 -P secureboot=true
 
-# Update a single host with dedicated flags for credentials
+# Update a baremetal host with dedicated flags for credentials
 $ kcli update baremetal-host -u admin -p admin 10.10.10.10 -P secureboot=true
 """
 
-ocdownload = """# Download 4.13 stable
-$ kcli download oc -P version=stable -P tag=4.13
+ocdownload = """# Download 4.19 stable
+$ kcli download oc -P version=stable -P tag=4.19
 
 # Download specific tag
-$ kcli download oc -P version=tag -P tag=4.11.16
+$ kcli download oc -P version=tag -P tag=4.16.4
 
 # Download nightly
-$ kcli download oc -P version=nightly -P tag=4.14
+$ kcli download oc -P version=nightly -P tag=4.19
 
 # Download older version from CI
-$ kcli download oc -P version=ci -P tag=4.10
+$ kcli download oc -P version=ci -P tag=4.14
 """
 
-ocmirrordownload = """# Download 4.13 stable
-$ kcli download oc-mirror -P version=stable -P tag=4.13
+ocmirrordownload = """# Download 4.19 stable
+$ kcli download oc-mirror -P version=stable -P tag=4.19
 
 # Download specific tag
-$ kcli download oc-mirror -P version=tag -P tag=4.11.16
+$ kcli download oc-mirror -P version=tag -P tag=4.16.4
 
 # Download nightly
-$ kcli download oc-mirror -P version=nightly -P tag=4.14
+$ kcli download oc-mirror -P version=nightly -P tag=4.20
 
 """
 
-openshiftdownload = """# Download 4.13 stable
-$ kcli download openshift-install -P version=stable -P tag=4.13
+openshiftdownload = """# Download latest stable
+$ kcli download openshift-install
+
+# Download older stable version
+$ kcli download openshift-install -P version=stable -P tag=4.14
 
 # Download specific tag
-$ kcli download openshift-install -P version=tag -P tag=4.11.16
+$ kcli download openshift-install -P version=stable -P tag=4.16.4
 
 # Download nightly
-$ kcli download openshift-install -P version=nightly -P tag=4.14
+$ kcli download openshift-install -P version=nightly -P tag=4.16
+
+# Download candidate version
+$ kcli download openshift-install -P tag=4.20.0-rc.1
 
 # Download older version from CI
-$ kcli download openshift-install -P version=ci -P tag=4.10
+$ kcli download openshift-install -P version=ci -P tag=4.14
 """
 
 securitygroupcreate = """# Create a security group named mygroup and opening tcp ports 22 and 25
@@ -754,19 +732,19 @@ $ kcli create network -P macvtap=true -P nic=eno2 mytap
 # Create a network with custom dnsmasq options
 $ kcli create network -c 192.168.123.0/24 -P arp-timeout=120 mynetwork
 
-# Create an ovn overlay network (on kubevirt) with a localnet topology and connected to br-ex bridge
+# Create an ovn overlay network (on KubeVirt) with a localnet topology and connected to br-ex bridge
 $ kcli create network -c 192.168.126.0/24 mynetwork
 
-# Create an ovn overlay network (on kubevirt) with a layer2 topology
+# Create an ovn overlay network (on KubeVirt) with a layer2 topology
 $ kcli create network -c 192.168.126.0/24 -P type=ovn -P topology=topology mynetwork
 
 # Do the same using an existing network attachment from some specific namespace
 $ kcli create network -c 192.168.126.0/24 -P type=ovn -P nad=default/othernad mynetwork
 
-# Create a br-ex network attachment definition using ovs cni (on kubevirt)
+# Create a br-ex network attachment definition using ovs cni (on KubeVirt)
 $ kcli create network -P type=ovs br-ex
 
-# Create a br-ex network attachment definition using ovs cni (on kubevirt)
+# Create a br-ex network attachment definition using ovs cni (on KubeVirt)
 $ kcli create network -P ovs=true br-ex
 
 # Create an ovs bridge br0 network (on libvirt)
@@ -848,13 +826,13 @@ $ kcli update vm ubuntu-20.04-server-cloudimg-amd64 -P template=true
 # Convert vm to template (vsphere specific)
 $ kcli update vm ubuntu-20.04-server-cloudimg-amd64 -P template=true
 
-# Add cpuflags to a vm (kvm specific)
+# Add cpuflags to a vm (KVM specific)
 $ kcli update vm -P cpuflags=[vmx] myvm
 
-# Remove cpuflags from a vm (kvm specific)
+# Remove cpuflags from a vm (KVM specific)
 $ kcli update vm -P cpuflags=[vmx] -P disable=true myvm
 
-# Add and remove cpuflags from a vm (kvm specific)
+# Add and remove cpuflags from a vm (KVM specific)
 $ kcli update vm -P cpuflags=['{"name": "vmx", "policy": "enable"}, {"name": "ss", "policy": "disable"}'] myvm
 """
 
@@ -870,9 +848,12 @@ $ kcli list vm -P plan=prod
 # Combine filters
 $ kcli list vm -P plan=prod -P status=up
 
-# Get vms whose ip starts with 192.168.122
+# Filter vms whose ip start with 192.168.122
 $ kcli list vm -P ip=192.168.122
 
-# Get vms whose name starts with myclu
+# Filter vms with a name that starts with myclu
 $ kcli list vm -P name=myclu
+
+# Filter vms which belong to a specific network
+$ kcli list vm -P network=baremetal
 """
