@@ -5,7 +5,7 @@ import json
 import os
 import re
 import sys
-from urllib.request import urlopen
+from urllib.request import urlopen, Request
 from time import sleep
 import yaml
 
@@ -14,6 +14,10 @@ def basename(path):
     return os.path.basename(path)
 
 
+def diskpath(path):
+    return path if path.startswith('/dev') else f"/dev/{path}"
+
+
 def dirname(path):
     return os.path.dirname(path)
 
@@ -25,7 +29,7 @@ def none(value):
 def base64(value):
     if value is None:
         return None
-    return str(b64encode(value.encode('utf-8')), 'utf-8')
+    return str(b64encode(str(value).encode('utf-8')), 'utf-8')
 
 
 def _type(value):
@@ -41,13 +45,10 @@ def _type(value):
         return 'list'
 
 
-def ocpnodes(cluster, platform, ctlplanes, workers):
-    ctlplanes = ['%s-ctlplane-%d' % (cluster, num) for num in range(ctlplanes)]
-    workers = ['%s-worker-%d' % (cluster, num) for num in range(workers)]
-    if platform in ['kubevirt', 'openstack', 'vsphere', 'packet']:
-        return ["%s-bootstrap-helper" % cluster] + ["%s-bootstrap" % cluster] + ctlplanes + workers
-    else:
-        return ["%s-bootstrap" % cluster] + ctlplanes + workers
+def kubenodes(cluster, ctlplanes=1, workers=1):
+    ctlplanes = [f'{cluster}-ctlplane-{num}' for num in range(ctlplanes)]
+    workers = [f'{cluster}-worker-{num}' for num in range(workers)]
+    return ctlplanes + workers
 
 
 def certificate(value):
@@ -71,7 +72,10 @@ def github_version(repo, version=None, tag_mode=False):
     if version is None or version == 'latest':
         obj = 'tags' if tag_mode else 'releases'
         tag_name = 'name' if tag_mode else 'tag_name'
-        data = json.loads(urlopen(f"https://api.github.com/repos/{repo}/{obj}", timeout=5).read())
+        request = Request(f"https://api.github.com/repos/{repo}/{obj}")
+        if 'GITHUB_TOKEN' in os.environ:
+            request.add_header('Authorization', f'Bearer: {os.environ["GITHUB_TOKEN"]}')
+        data = json.loads(urlopen(request, timeout=5).read())
         if 'message' in data and data['message'] == 'Not Found':
             return ''
         tags = sorted([x[tag_name] for x in data if stable_release(x, tag_mode)],
@@ -128,10 +132,10 @@ fi """ % (timeout, namespace, csv, csv, csv)
 
 
 def local_ip(net, wrap=False):
-    c = "ip a s %s 2>/dev/null | egrep 'inet6?[[:space:]][^fe]' | head -1 | awk '{print $2}' | cut -d '/' -f 1" % net
+    c = "ip a s %s 2>/dev/null | grep -E 'inet6?[[:space:]][^fe]' |head -1| awk '{print $2}' | cut -d '/' -f 1" % net
     result = os.popen(c).read().strip()
     if result == '' and net == 'default':
-        c = "ip a s virbr0 2>/dev/null | egrep 'inet6?[[:space:]][^fe]' | head -1 | awk '{print $2}' | cut -d '/' -f 1"
+        c = "ip a s virbr0 2>/dev/null | grep -E 'inet6?[[:space:]][^fe]' |head -1| awk '{print $2}' | cut -d '/' -f 1"
         result = os.popen(c).read().strip()
     if wrap and ':' in result:
         result = '[%s]' % result
@@ -142,11 +146,11 @@ def network_ip(network, num=0, version=False):
     try:
         ip = str(ip_network(network)[num])
         if version and ':' in network:
-            return "[%s]" % ip
+            return f"[{ip}]"
         else:
             return ip
     except Exception as e:
-        print("Error processing filter network_ip with %s and %s. Got %s" % (network, num, e))
+        print(f"Error processing filter network_ip with {network} and {num}. Got {e}")
         sys.exit(1)
 
 
@@ -195,8 +199,8 @@ def has_ctlplane(_list):
     return False
 
 
-def count(string, char):
-    return string.count(char)
+def count(var, char):
+    return str(var).count(char)
 
 
 def pwd_path(path):
@@ -207,11 +211,30 @@ def pwd_path(path):
         return path
 
 
-jinjafilters = {'basename': basename, 'dirname': dirname, 'ocpnodes': ocpnodes, 'none': none, 'type': _type,
-                'certificate': certificate, 'base64': base64, 'github_version': github_version,
+def real_path(path):
+    return path and os.path.realpath(path)
+
+
+def read_file(path):
+    with open(path, 'r') as f:
+        return f.read()
+
+
+def min_ocp_version(version1, version2):
+    return version1 if version1 < version2 else version2
+
+
+def max_ocp_version(version1, version2):
+    return version1 if version1 > version2 else version2
+
+
+jinjafilters = {'basename': basename, 'dirname': dirname, 'diskpath': diskpath, 'kubenodes': kubenodes, 'none': none,
+                'type': _type, 'certificate': certificate, 'base64': base64, 'github_version': github_version,
                 'defaultnodes': defaultnodes, 'wait_crd': wait_crd, 'local_ip': local_ip, 'network_ip': network_ip,
                 'kcli_info': kcli_info, 'find_manifests': find_manifests, 'exists': exists, 'ipv6_wrap': ipv6_wrap,
-                'has_ctlplane': has_ctlplane, 'wait_csv': wait_csv, 'count': count, 'pwd_path': pwd_path}
+                'has_ctlplane': has_ctlplane, 'wait_csv': wait_csv, 'count': count, 'pwd_path': pwd_path,
+                'min_ocp_version': min_ocp_version, 'max_ocp_version': max_ocp_version, 'real_path': real_path,
+                'read_file': read_file}
 
 
 class FilterModule(object):
