@@ -112,9 +112,9 @@ class Kibm(object):
                reservehost=False, start=True, keys=[], cmds=[], ips=None,
                netmasks=None, gateway=None, nested=True, dns=None, domain=None,
                tunnel=False, files=[], enableroot=True, alias=[], overrides={},
-               tags=[], storemetadata=False, sharedfolders=[], kernel=None, initrd=None, cmdline=None,
-               cpuhotplug=False, memoryhotplug=False, numamode=None, numa=[], pcidevices=[], tpm=False,
-               placement=[], autostart=False, rng=False, metadata={}, securitygroups=[], vmuser=None):
+               tags=[], storemetadata=False, sharedfolders=[], cmdline=None, cpuhotplug=False, memoryhotplug=False,
+               numamode=None, numa=[], pcidevices=[], tpm=False, placement=[], autostart=False, rng=False, metadata={},
+               securitygroups=[], vmuser=None, guestagent=True):
         try:
             vpcs = self.conn.list_vpcs().result['vpcs']
             for vpc in vpcs:
@@ -433,9 +433,11 @@ class Kibm(object):
                 return yamlinfo
         ips = []
         for network in vm['network_interfaces']:
-            if network['id'] not in floating_ips:
-                continue
-            ips.append(floating_ips[network['id']]['address'])
+            if network['id'] in floating_ips:
+                ips.append(floating_ips[network['id']]['address'])
+        for a in vm['network_attachments']:
+            if 'virtual_network_interface' in a and a['virtual_network_interface']['id'] in floating_ips:
+                ips.append(floating_ips[a['virtual_network_interface']['id']]['address'])
         ip = ','.join(ips)
         # zone = vm['zone']['name']
         image = vm['image']['name']
@@ -743,7 +745,7 @@ class Kibm(object):
             return {'result': 'failure', 'reason': f'Unable to delete image. Hit {e}'}
         return {'result': 'success'}
 
-    def add_image(self, url, pool, short=None, cmd=None, name=None, size=None, convert=False):
+    def add_image(self, url, pool, short=None, cmds=[], name=None, size=None, convert=False):
         cos_id = self.cos_resource_instance_id.split(':')[7]
         identity_client = IamIdentityV1(authenticator=self.authenticator)
         api_key_detail = identity_client.get_api_keys_details(iam_api_key=self.iam_api_key).get_result()
@@ -1463,3 +1465,7 @@ class Kibm(object):
 
     def list_dns_zones(self):
         return [d['name'] for d in self.dns.list_zones().get_result()['result']]
+
+    def detach_disks(self, name):
+        print("not implemented")
+        return {'result': 'success'}
