@@ -23,33 +23,44 @@ class Kopenstack(object):
     """
     def __init__(self, host='127.0.0.1', version='3', port=None, user='root', password=None, debug=False, project=None,
                  domain='Default', auth_url=None, ca_file=None, external_network=None, region_name=None,
-                 glance_disk=False, auth_type='password', auth_token=None):
+                 glance_disk=False, auth_type='password', auth_token=None, application_credential_id=None,
+                 application_credential_secret=None):
         self.debug = debug
         self.host = host
         loader = loading.get_plugin_loader(auth_type)
         if auth_type == 'password':
             auth = loader.load_from_options(auth_url=auth_url, username=user, password=password, project_name=project,
                                             user_domain_name=domain, project_domain_name=domain)
-        else:
+        elif auth_type == 'v3applicationcredential':
+            auth = loader.load_from_options(auth_url=auth_url, application_credential_id=application_credential_id,
+                                            application_credential_secret=application_credential_secret)
+        elif auth_type == 'token':
             auth = loader.load_from_options(auth_url=auth_url, token=auth_token, project_id=project)
-        if ca_file is not None:
-            sess = session.Session(auth=auth, verify=os.path.expanduser(ca_file))
         else:
-            sess = session.Session(auth=auth)
+            error(f"Unsupported auth_type {auth_type}")
+            self.conn = None
+            return
+        if ca_file is not None:
+            cacert = os.path.expanduser(ca_file)
+            sess_data = {'auth': auth, 'verify': cacert}
+        else:
+            cacert = None
+            sess_data = {'auth': auth, 'verify': False}
+        sess = session.Session(**sess_data)
         self.nova = novaclient.Client(version, session=sess, region_name=region_name)
         self.glance = glanceclient(version, session=sess, region_name=region_name)
         self.cinder = cinderclient.Client('3', session=sess, region_name=region_name)
         self.neutron = neutronclient(session=sess, region_name=region_name)
         os_options = {'user_domain_name': domain, 'project_domain_name': domain, 'project_name': project}
-        self.swift = swiftclient.Connection(authurl=auth_url, user=user, key=password, os_options=os_options,
-                                            auth_version='3')
+        self.swift = swiftclient.Connection(session=sess, os_options=os_options, cacert=cacert,
+                                            insecure=ca_file is not None)
         self.conn = self.nova
         self.project = project
         self.external_network = external_network
         self.region_name = region_name
         self.glance_disk = glance_disk
+        self.ca_file = ca_file
 
-# should cleanly close your connection, if needed
     def close(self):
         print("not implemented")
 
@@ -73,9 +84,9 @@ class Kopenstack(object):
                reservehost=False, start=True, keys=[], cmds=[], ips=None,
                netmasks=None, gateway=None, nested=True, dns=None, domain=None,
                tunnel=False, files=[], enableroot=True, alias=[], overrides={},
-               tags=[], storemetadata=False, sharedfolders=[], kernel=None, initrd=None,
-               cmdline=None, placement=[], autostart=False, cpuhotplug=False, memoryhotplug=False, numamode=None,
-               numa=[], pcidevices=[], tpm=False, rng=False, metadata={}, securitygroups=[], vmuser=None):
+               tags=[], storemetadata=False, sharedfolders=[], cmdline=None, placement=[], autostart=False,
+               cpuhotplug=False, memoryhotplug=False, numamode=None, numa=[], pcidevices=[], tpm=False, rng=False,
+               metadata={}, securitygroups=[], vmuser=None, guestagent=True):
         default_diskinterface = diskinterface
         glance = self.glance
         nova = self.nova
@@ -416,12 +427,15 @@ class Kopenstack(object):
         yamlinfo['numcpus'] = flavor.vcpus
         yamlinfo['nets'] = []
         index = 0
+        ips = []
         for key in list(vm.addresses):
             entry1 = vm.addresses[key]
             for entry2 in entry1:
                 mac = entry2['OS-EXT-IPS-MAC:mac_addr']
                 if entry2['OS-EXT-IPS:type'] == 'floating':
-                    yamlinfo['ip'] = entry2['addr']
+                    publicip = entry2['addr']
+                    yamlinfo['ip'] = publicip
+                    ips.append(publicip)
                 else:
                     net = {'device': f'eth{index}', 'mac': mac, 'net': key, 'type': entry2['addr']}
                     if index == 0:
@@ -429,7 +443,11 @@ class Kopenstack(object):
                     yamlinfo['nets'].append(net)
                     index += 1
         if 'ip' not in yamlinfo and 'privateip' in yamlinfo:
-            yamlinfo['ip'] = yamlinfo['privateip']
+            privateip = yamlinfo['privateip']
+            yamlinfo['ip'] = privateip
+            ips.append(privateip)
+        if len(ips) > 1:
+            yamlinfo['ips'] = ips
         disks = []
         for disk in vm._info['os-extended-volumes:volumes_attached']:
             diskid = disk['id']
@@ -499,6 +517,15 @@ class Kopenstack(object):
                 if entry2['OS-EXT-IPS:type'] == 'floating':
                     vm_floating_ips.append(entry2['addr'])
         vm.delete()
+
+        # Wait until it's gone
+        while True:
+            try:
+                nova.servers.get(vm.id)
+                sleep(1)
+            except novaclient.exceptions.NotFound:
+                break
+
         for floating in vm_floating_ips:
             floatingid = floating_ips[floating]
             try:
@@ -803,7 +830,7 @@ class Kopenstack(object):
                 return {'result': 'success'}
         return {'result': 'failure', 'reason': f"Image {image} not found"}
 
-    def add_image(self, url, pool, short=None, cmd=None, name=None, size=None, convert=False):
+    def add_image(self, url, pool, short=None, cmds=[], name=None, size=None, convert=False):
         downloaded = False
         shortimage = os.path.basename(url).split('?')[0]
         if name is not None and name.endswith('iso'):
@@ -835,15 +862,16 @@ class Kopenstack(object):
             shortimage = shortimage.replace('.gz', '').replace('.xz', '').replace('.bz2', '').replace('.zst', '')
             image_path = image_path.replace('.gz', '').replace('.xz', '').replace('.bz2', '').replace('.zst', '')
         disk_format = 'iso' if shortimage.endswith('iso') else 'qcow2'
-        if cmd is not None:
-            pprint(f"Running {cmd} on {image_path}")
-            if disk_format == 'iso':
-                if image_path not in cmd:
-                    cmd += f" {image_path}"
-                os.system(cmd)
-            elif which('virt-customize') is not None:
-                cmd = f"virt-customize -a {image_path} --run-command '{cmd}'"
-                os.system(cmd)
+        if cmds:
+            for cmd in cmds:
+                pprint(f"Running {cmd} on {image_path}")
+                if disk_format == 'iso':
+                    if image_path not in cmd:
+                        cmd += f" {image_path}"
+                    os.system(cmd)
+                elif which('virt-customize') is not None:
+                    cmd = f"virt-customize -a {image_path} --run-command '{cmd}'"
+                    os.system(cmd)
         glanceimage = self.glance.images.create(name=shortimage, disk_format=disk_format, container_format='bare')
         self.glance.images.upload(glanceimage.id, open(image_path, 'rb'))
         if downloaded:
@@ -1288,3 +1316,20 @@ class Kopenstack(object):
     def list_dns_zones(self):
         print("not implemented")
         return []
+
+    def detach_disks(self, name):
+        nova = self.nova
+        cinder = self.cinder
+        try:
+            vm = nova.servers.find(name=name)
+        except:
+            error(f"VM {name} not found")
+            return {'result': 'failure', 'reason': f"VM {name} not found"}
+        all_disks = vm._info['os-extended-volumes:volumes_attached']
+        vm_disks = all_disks[1:] if len(all_disks) > 1 else []
+        for disk in vm_disks:
+            volume = cinder.volumes.get(disk['id'])
+            for attachment in volume.attachments:
+                if attachment['server_id'] == vm.id:
+                    cinder.volumes.detach(volume, attachment['attachment_id'])
+        return {'result': 'success'}
