@@ -105,9 +105,9 @@ class KOvirt(object):
                reservehost=False, start=True, keys=[], cmds=[], ips=None,
                netmasks=None, gateway=None, nested=True, dns=None, domain=None,
                tunnel=False, files=[], enableroot=True, alias=[], overrides={},
-               tags=[], storemetadata=False, sharedfolders=[], kernel=None, initrd=None,
-               cmdline=None, placement=[], autostart=False, cpuhotplug=False, memoryhotplug=False, numamode=None,
-               numa=[], pcidevices=[], tpm=False, rng=False, metadata={}, securitygroups=[], vmuser=None):
+               tags=[], storemetadata=False, sharedfolders=[], cmdline=None, placement=[], autostart=False,
+               cpuhotplug=False, memoryhotplug=False, numamode=None, numa=[], pcidevices=[], tpm=False, rng=False,
+               metadata={}, securitygroups=[], vmuser=None, guestagent=True):
         ip = None
         initialization = None
         memory = memory * 1024 * 1024
@@ -928,6 +928,26 @@ release-cursor=shift+f12""".format(address=address, port=port, ticket=ticket.val
                 volumes[diskname] = {'pool': pool, 'path': path}
         return volumes
 
+    def detach_disks(self, name):
+        pprint(f"Detaching non primary disks from {name}")
+        vmsearch = self.vms_service.list(search=f'name={name}')
+        if not vmsearch:
+            error(f"VM {name} not found")
+            return {'result': 'failure', 'reason': f"VM {name} not found"}
+        vm = self.vms_service.vm_service(vmsearch[0].id)
+        disk_attachments_service = vm.disk_attachments_service()
+        all_disks = disk_attachments_service.list()
+        vm_disks = all_disks[1:] if len(all_disks) > 1 else []
+        for disk in vm_disks:
+            disk_attachment_service = disk_attachments_service.attachment_service(disk.id)
+            disk_attachment_service.update(types.DiskAttachment(active=False))
+            while True:
+                sleep(5)
+                disk_attachment = disk_attachment_service.get()
+                if not disk_attachment.active:
+                    break
+        return {'result': 'success'}
+
     def add_nic(self, name, network, model='virtio'):
         vmsearch = self.vms_service.list(search=f'name={name}')
         if not vmsearch:
@@ -996,7 +1016,7 @@ release-cursor=shift+f12""".format(address=address, port=port, ticket=ticket.val
                 return {'result': 'success'}
         return {'result': 'failure', 'reason': f"Image {image} not found"}
 
-    def add_image(self, url, pool, short=None, cmd=None, name=None, size=None, convert=False):
+    def add_image(self, url, pool, short=None, cmds=[], name=None, size=None, convert=False):
         downloaded = False
         shortimage = os.path.basename(url).split('?')[0]
         iso = True if shortimage.endswith('.iso') or name.endswith('.iso') else False
